@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -20,6 +20,7 @@ import logging
 import os
 import pwd
 import shutil
+import stat
 import sys
 
 
@@ -147,7 +148,15 @@ class ConfigFile(object):
             if not self.merge:
                 self._delete_path(dest)
             self._create_parent_dirs(dest)
-            self._merge_directories(source, dest)
+            try:
+                self._merge_directories(source, dest)
+            except OSError:
+                # If a source is tried to merge with a read-only mount, it
+                # may throw an OSError. Because we don't print the source or
+                # dest anywhere, let's catch the exception and log a better
+                # message to help with tracking down the issue.
+                LOG.error('Unable to merge %s with %s', source, dest)
+                raise
 
     def _cmp_file(self, source, dest):
         # check exsit
@@ -156,7 +165,7 @@ class ConfigFile(object):
                 not os.path.exists(dest)):
             return False
         # check content
-        with open(source) as f1, open(dest) as f2:
+        with open(source, 'rb') as f1, open(dest, 'rb') as f2:
             if f1.read() != f2.read():
                 LOG.error('The content of source file(%s) and'
                           ' dest file(%s) are not equal.', source, dest)
@@ -196,8 +205,8 @@ class ConfigFile(object):
                     return False
             for file_ in files:
                 full_path = os.path.join(root, file_)
-                dest_full_path = os.path.join(dest, os.path.relpath(source,
-                                                                    full_path))
+                dest_full_path = os.path.join(dest, os.path.relpath(full_path,
+                                                                    source))
                 if not self._cmp_file(full_path, dest_full_path):
                     return False
         return True
@@ -217,8 +226,9 @@ class ConfigFile(object):
             # otherwise means copy the source to dest
             if dest.endswith(os.sep):
                 dest = os.path.join(dest, os.path.basename(source))
-            if os.path.isdir(source) and not self._cmp_dir(source, dest):
-                bad_state_files.append(source)
+            if os.path.isdir(source):
+                if not self._cmp_dir(source, dest):
+                    bad_state_files.append(source)
             elif not self._cmp_file(source, dest):
                 bad_state_files.append(source)
         if len(bad_state_files) != 0:
@@ -360,6 +370,15 @@ def handle_permissions(config):
                     perm = ''.join([perm[:1], 'o', perm[1:]])
                 perm = int(perm, base=0)
 
+                # Ensure execute bit on directory if read bit is set
+                if os.path.isdir(path):
+                    if perm & stat.S_IRUSR:
+                        perm |= stat.S_IXUSR
+                    if perm & stat.S_IRGRP:
+                        perm |= stat.S_IXGRP
+                    if perm & stat.S_IROTH:
+                        perm |= stat.S_IXOTH
+
                 try:
                     os.chmod(path, perm)
                 except OSError:
@@ -396,7 +415,7 @@ def execute_config_strategy(config):
 
 
 def execute_config_check(config):
-    for data in config['config_files']:
+    for data in config.get('config_files', []):
         config_file = ConfigFile(**data)
         config_file.check()
 
